/* This file is part of the KDE project

   Copyright (C) 2008 Javier Goday <jgoday @ gmail.com>
   Copyright (C) 2007 Batiste Bieler <batiste@dosimple.ch>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
*/
#include "katetreeview.h"

#include <QHeaderView>

#include <KDebug>
#include <KUrl>
#include <kate/application.h>
#include <kate/documentmanager.h>
#include <kate/mainwindow.h>
#include <ktexteditor/document.h>

KateTreeView::KateTreeView(QWidget *parent, Kate::MainWindow *window) : QTreeView(parent)
{
    m_katewindow = window;
    m_model = new QDirModel();
    m_model->setSorting(QDir::DirsFirst | QDir::Name);

    setModel(m_model);
    hideDetailsView();

    setSelectionMode(QAbstractItemView::MultiSelection);
    setAlternatingRowColors(true);

    connect(this, SIGNAL(doubleClicked(const QModelIndex &)), 
                  SLOT(activateDocument(const QModelIndex &)));
}

KateTreeView::~KateTreeView()
{
}

QString KateTreeView::currentPath() const
{
    return m_model->filePath(rootIndex());
}

void KateTreeView::openUrl(const QString &url)
{
    setRootIndex(m_model->index(url));
    selectOpenedDocuments();
    emit directoryChanged(url);
}

void KateTreeView::moveUp()
{
    KUrl currentUrl = m_model->filePath(rootIndex());
    
    setRootIndex(m_model->index(currentUrl.upUrl().path()));
    selectOpenedDocuments();
    emit directoryChanged(currentUrl.upUrl().path());
}

void KateTreeView::showDetailsView()
{
    header()->showSection(1);
    header()->showSection(2);
    header()->showSection(3);
}

void KateTreeView::hideDetailsView()
{
    header()->hideSection(1);
    header()->hideSection(2);
    header()->hideSection(3);
}

void KateTreeView::activateDocument(const QModelIndex &index)
{
    if (index.isValid()) {
        QFileInfo info(m_model->filePath(index));
        if (info.isFile()) {
            m_katewindow->openUrl(KUrl(m_model->filePath(index)));
        }
        else if (info.isDir()) {
            setRootIndex(index);
            selectOpenedDocuments();

            emit directoryChanged(m_model->filePath(index));
        }
    }
}

void KateTreeView::selectOpenedDocuments()
{
    // Select all documents from the document manager
    QItemSelectionModel *s_model = selectionModel();
    foreach (KTextEditor::Document *doc, Kate::application()->documentManager()->documents()) {
        s_model->select(m_model->index(doc->url().path()), QItemSelectionModel::Select);
    }
}
