/* This file is part of the KDE project

   Copyright (C) 2008 Javier Goday <jgoday @ gmail.com>
   Copyright (C) 2007 Batiste Bieler <batiste@dosimple.ch>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
*/
#ifndef KATETREEVIEW_H
#define KATETREEVIEW_H

#include <QObject>
#include <QDirModel>
#include <QTreeView>

namespace Kate {
    class MainWindow;
};

class KateTreeView : public QTreeView
{
    Q_OBJECT
public:
    KateTreeView(QWidget *parent, Kate::MainWindow *window);
    ~KateTreeView();

    /**
    * Returns the current root directory in the QDirModel
    */
    QString currentPath() const;

public slots:
    /**
    * Sets the root directory to parameter url
    */
    void openUrl(const QString &url);
    /**
    * Sets the currentPath() parent directory as the root directory
    */
    void moveUp();
    /**
    * Shows the Size, type, and date modified headers
    */
    void showDetailsView();
    /**
    * Hides the size, type and  date modified headers
    */
    void hideDetailsView();

signals:
    /**
    * emited when the root directory changes
    */
    void directoryChanged(const QString &);

private slots:
    /**
    * Opens a document in the kate documentmanager
    */
    void activateDocument(const QModelIndex &);
    /**
    * Mark nodes selected for each opened document 
    */
    void selectOpenedDocuments();

private:
    QDirModel *m_model;
    Kate::MainWindow *m_katewindow;
};

#endif
