/* This file is part of the KDE project

   Copyright (C) 2008 Javier Goday <jgoday @ gmail.com>
   Copyright (C) 2007 Batiste Bieler <batiste@dosimple.ch>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
*/
#include "katetreeviewplugin.h"
#include "katetreeview.h"
#include "katetreeviewtoolbar.h"

#include <QLabel>
#include <QVBoxLayout>

#include <kate/application.h>
#include <ktexteditor/document.h>
#include <ktexteditor/view.h>
#include <kdebug.h>
#include <kgenericfactory.h>

K_EXPORT_COMPONENT_FACTORY(katetreeviewplugin, KGenericFactory<KateTreeViewPlugin>("katetreeviewplugin"))

KateTreeViewPlugin::KateTreeViewPlugin(QObject *parent, const QStringList &parameters) :
    Kate::Plugin(qobject_cast <Kate::Application *> (parent))
{
    Q_UNUSED (parameters)
}

KateTreeViewPlugin::~KateTreeViewPlugin()
{/*
    delete m_view;*/
}

Kate::PluginView *KateTreeViewPlugin::createView(Kate::MainWindow *window)
{
    m_view = new KateTreeViewPluginView(window);
    return m_view;
}

KateTreeViewPluginView::KateTreeViewPluginView(Kate::MainWindow *window) :
    Kate::PluginView(window)
{
    QWidget *toolview = window->createToolView ("kate_private_plugin_katetreeviewplugin", 
                    Kate::MainWindow::Left, SmallIcon("view-list-tree"), 
                    i18n("TreeView"));

    QVBoxLayout *box = new QVBoxLayout();
    QWidget *widget = new QWidget(toolview);
    widget->setLayout(box);

    m_treeview = new KateTreeView(widget, window);
    m_toolbar = new KateTreeViewToolbar(widget, window, m_treeview);
    m_directory = new QLabel();
    m_directory->setAlignment(Qt::AlignRight);

    box->addLayout(m_toolbar);
    box->addWidget(m_directory);
    box->addWidget(m_treeview);

    connect(m_treeview, SIGNAL(directoryChanged(const QString &)),
                        SLOT(setCurrentDirectory(const QString &)));
}

KateTreeViewPluginView::~KateTreeViewPluginView()
{
    delete m_treeview->parentWidget();
}

void KateTreeViewPluginView::setCurrentDirectory(const QString &dir)
{
    m_directory->setText(dir);
}
