/* This file is part of the KDE project

   Copyright (C) 2008 Javier Goday <jgoday @ gmail.com>

   Use the filesystem browser plugin boomkark files copyrighted by
   Copyright (C) 2001 Christoph Cullmann <cullmann@kde.org>
   Copyright (C) 2001 Joseph Wenninger <jowenn@kde.org>
   Copyright (C) 2001 Anders Lund <anders.lund@lund.tdcadsl.dk>
   Copyright (C) 2007 Mirko Stocker <me@misto.ch>

   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public
   License as published by the Free Software Foundation; either
   version 2 of the License, or (at your option) any later version.
*/
#include "katetreeviewtoolbar.h"
#include "katetreeviewbookmarkowner.h"
#include "katetreeview.h"

#include <QButtonGroup>
#include <QPushButton>

#include <kate/mainwindow.h>

#include <KActionCollection>
#include <KActionMenu>
#include <KIcon>
#include <KBookmarkMenu>
#include <KBookmarkManager>
#include <KStandardDirs>

KateTreeViewToolbar::KateTreeViewToolbar(QWidget *parent, Kate::MainWindow *window, KateTreeView *treeview) : 
        QHBoxLayout(parent)
{
    Q_UNUSED(window)

    m_treeview = treeview;

    KActionCollection *actionCollection = new KActionCollection(this);

    QPushButton *upButton = new QPushButton(KIcon("go-up"), "");

    QPushButton *listView = new QPushButton(KIcon("view-list-text"), "");
    QPushButton *detailsView = new QPushButton(KIcon("view-list-details"), "");

    listView->setCheckable(true);
    detailsView->setCheckable(true);
    listView->setChecked(true);

    QButtonGroup *viewGroup = new QButtonGroup(parent);
    viewGroup->setExclusive(true);
    viewGroup->addButton(listView);
    viewGroup->addButton(detailsView);

    KActionMenu *bookmarkAction = new KActionMenu(KIcon("bookmarks"), i18n("Bookmarks"), this);
    actionCollection->addAction("bookmarks", bookmarkAction);

    QString file = KStandardDirs::locate("data", "kate/fsbookmarks.xml");
    if (file.isEmpty())
        file = KStandardDirs::locateLocal("data", "kate/fsbookmarks.xml");

    KBookmarkManager *manager = KBookmarkManager::managerForFile(file, "kate");
    manager->setUpdate( true );

    KateTreeViewBookmarkOwner *bookmarkOwner = new KateTreeViewBookmarkOwner(this, treeview);

    KBookmarkMenu *m_bookmarkMenu = new KBookmarkMenu(manager, 
                                                      bookmarkOwner, 
                                                      bookmarkAction->menu(), actionCollection);

    QPushButton *bookmarkButton = new QPushButton(KIcon("bookmarks"), "");
    bookmarkButton->setMenu(bookmarkAction->menu());

    addWidget(upButton);
    addWidget(listView);
    addWidget(detailsView);
    addWidget(bookmarkButton);

    connect(upButton, SIGNAL(clicked()), m_treeview, SLOT(moveUp()));
    connect(listView, SIGNAL(clicked()), m_treeview, SLOT(hideDetailsView()));
    connect(detailsView, SIGNAL(clicked()), m_treeview, SLOT(showDetailsView()));
    connect(bookmarkOwner, SIGNAL(openUrl(const QString &)), m_treeview, SLOT(openUrl(const QString &)));
}

KateTreeViewToolbar::~KateTreeViewToolbar()
{
}
